# FEA utils

Useful code snippets and helper methods that Future Energy Associates frequently use for data science.

Install with `pip install feautils`

## Deploy to pypi

Publishing a package is now done with the `Trusted Publisher Management` workflow via github. See this example for more details 

https://medium.com/@blackary/publishing-a-python-package-from-github-to-pypi-in-2024-a6fb8635d45d
